%
% Filename:    xup_virtex_ii_pro_development_system_postgeneration.m
%
% Description: Defines board-specific parameters (e.g. ucf file, 
%              non-memory mapped ports) before invoking the 
%              generic JTAG post-generation callback function.

function st = xup_virtex_ii_pro_development_system_postgeneration(params)

  % Device position in the boundary scan chain (beginning at 1).
  params.('boundary_scan_position') = '3';

  % Instruction register length of every scan chain device. 
  params.('instruction_register_lengths') = '[16, 8, 14]';

  % Constraints file to use for this compilation target.
  params.('ucf_template') = 'xup_virtex_ii_pro_development_system.ucf'; 

  % Define non-memory mapped ports.
  non_mm_ports.('LED') = {'out', 4};
  non_mm_ports.('PushButtons') = {'in', 5};
  non_mm_ports.('Switches') = {'in', 4};
  non_mm_ports.('VGA_VSYNCH') = {'out', 1};
  non_mm_ports.('VGA_HSYNCH') = {'out', 1};
  non_mm_ports.('VGA_OUT_BLANK_Z') = {'out', 1};
  non_mm_ports.('VGA_COMP_SYNCH') = {'out', 1};
  non_mm_ports.('VGA_OUT_PIXEL_CLOCK') = {'out', 1};
  non_mm_ports.('VGA_OUT_RED') = {'out', 8};
  non_mm_ports.('VGA_OUT_GREEN') = {'out', 8};
  non_mm_ports.('VGA_OUT_BLUE') = {'in', 8};
  non_mm_ports.('AC97_SDATA_OUT') = {'out', 1};
  non_mm_ports.('AC97_SDATA_IN') = {'in', 1};
  non_mm_ports.('AC97_SYNCH') = {'in', 1};
  non_mm_ports.('AC97_BIT_CLOCK') = {'out', 1};
  non_mm_ports.('AUDIO_RESET_Z') = {'out', 1};
  non_mm_ports.('BEEP_TONE_IN') = {'in', 1};
  params.('non_memory_mapped_ports') = non_mm_ports;

  % You may use your own top-level netlist file by uncommenting the 
  % following line and setting the 'vendor_toplevel' field accordingly.
  % params.('vendor_toplevel') = 'xup_virtex_ii_pro_development_system_toplevel';

  % If you use your own top-level, you must tell SysGen what netlist 
  % files are required.  Set the 'vendor_netlists' field to a cell 
  % array listing the required file names. 
  % params.('vendor_netlists') = {'xup_virtex_ii_pro_development_system_toplevel.ngc','xup_virtex_ii_pro_development_system.edf'};

  % Invoke the JTAG post-generation callback function to run
  % Xilinx tools and create a run-time co-simulation token.
  try
    st = xlJTAGPostGeneration(params);
  catch
    errordlg(['-- An unknown error was encountered while running ' ...
             'the JTAG hardware co-simulation flow for the ' ...
             'XUP Virtex-II Pro Development System']);
    st = 1;
  end
